package com.ruoyi.app.service;

import com.ruoyi.app.domain.AppWcsTask;

import java.util.List;

/**
 * 【请填写功能名称】Service接口
 *
 * @author ruoyi
 * @date 2025-01-15
 */
public interface IAppWcsTaskService
{
    /**
     * 查询【请填写功能名称】
     *
     * @param wcsTaskId 【请填写功能名称】主键
     * @return 【请填写功能名称】
     */
    public AppWcsTask selectAppWcsTaskByWcsTaskId(String wcsTaskId);

    /**
     * 查询【请填写功能名称】列表
     *
     * @param appWcsTask 【请填写功能名称】
     * @return 【请填写功能名称】集合
     */
    public List<AppWcsTask> selectAppWcsTaskList(AppWcsTask appWcsTask);

    /**
     * 新增【请填写功能名称】
     *
     * @param appWcsTask 【请填写功能名称】
     * @return 结果
     */
    public int insertAppWcsTask(AppWcsTask appWcsTask);

    /**
     * 批量新增
     * @param appWcsTaskList 任务
     * @return 结果
     */
    int batchInsertAppWcsTask(List<AppWcsTask> appWcsTaskList);

    /**
     * 修改【请填写功能名称】
     *
     * @param appWcsTask 【请填写功能名称】
     * @return 结果
     */
    public int updateAppWcsTask(AppWcsTask appWcsTask);

    /**
     * 批量删除【请填写功能名称】
     *
     * @param wcsTaskIds 需要删除的【请填写功能名称】主键集合
     * @return 结果
     */
    public int deleteAppWcsTaskByWcsTaskIds(String[] wcsTaskIds);

    /**
     * 删除【请填写功能名称】信息
     *
     * @param wcsTaskId 【请填写功能名称】主键
     * @return 结果
     */
    public int deleteAppWcsTaskByWcsTaskId(String wcsTaskId);
}
