package com.ruoyi.web.controller.app;

import java.util.List;
import javax.servlet.http.HttpServletResponse;

import com.ruoyi.app.domain.AppWcsTask;
import com.ruoyi.app.domain.AppWcsTaskBak;
import com.ruoyi.app.service.IAppWcsTaskService;
import com.ruoyi.common.annotation.Anonymous;
import com.ruoyi.web.controller.section.EnhanceDataList;
import com.ruoyi.web.domain.PmsOrderInRequest;
import io.swagger.annotations.ApiOperation;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 【请填写功能名称】Controller
 *
 * @author ruoyi
 * @date 2025-01-15
 */
@RestController
@RequestMapping("/app/wcsTask")
public class AppWcsTaskController extends BaseController
{
    @Autowired
    private IAppWcsTaskService appWcsTaskService;

    /**
     * 查询【请填写功能名称】列表
     */
    @PreAuthorize("@ss.hasPermi('system:task:list')")
    @GetMapping("/list")
    @EnhanceDataList(entityType = AppWcsTask.class)
    public TableDataInfo list(AppWcsTask appWcsTask)
    {
        startPage();
        List<AppWcsTask> list = appWcsTaskService.selectAppWcsTaskList(appWcsTask);
        return getDataTable(list);
    }

    /**
     * 导出【请填写功能名称】列表
     */
    @PreAuthorize("@ss.hasPermi('system:task:export')")
    @Log(title = "【请填写功能名称】", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, AppWcsTask appWcsTask)
    {
        List<AppWcsTask> list = appWcsTaskService.selectAppWcsTaskList(appWcsTask);
        ExcelUtil<AppWcsTask> util = new ExcelUtil<AppWcsTask>(AppWcsTask.class);
        util.exportExcel(response, list, "【请填写功能名称】数据");
    }

    /**
     * 获取【请填写功能名称】详细信息
     */
    @PreAuthorize("@ss.hasPermi('system:task:query')")
    @GetMapping(value = "/{wcsTaskId}")
    public AjaxResult getInfo(@PathVariable("wcsTaskId") String wcsTaskId)
    {
        return success(appWcsTaskService.selectAppWcsTaskByWcsTaskId(wcsTaskId));
    }

    /**
     * 新增【请填写功能名称】
     */
    @PreAuthorize("@ss.hasPermi('system:task:add')")
    @Log(title = "【请填写功能名称】", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody AppWcsTask appWcsTask)
    {
        return toAjax(appWcsTaskService.insertAppWcsTask(appWcsTask));
    }

    /**
     * 修改【请填写功能名称】
     */
    @PreAuthorize("@ss.hasPermi('system:task:edit')")
    @Log(title = "【请填写功能名称】", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody AppWcsTask appWcsTask)
    {
        return toAjax(appWcsTaskService.updateAppWcsTask(appWcsTask));
    }

    /**
     * 删除【请填写功能名称】
     */
    @PreAuthorize("@ss.hasPermi('system:task:remove')")
    @Log(title = "【请填写功能名称】", businessType = BusinessType.DELETE)
    @DeleteMapping("/{wcsTaskIds}")
    public AjaxResult remove(@PathVariable String[] wcsTaskIds)
    {
        return toAjax(appWcsTaskService.deleteAppWcsTaskByWcsTaskIds(wcsTaskIds));
    }


}
